from PIL import Image
import colorsys

def analyze_image(image_path):
    with Image.open(image_path) as img:
        pixels = list(img.getdata())
        darkest = min(pixels, key=lambda x: sum(x[:3]))
        lightest = max(pixels, key=lambda x: sum(x[:3]))
    return darkest[:3], lightest[:3]

def rgb_to_hex(rgb):
    return '#{:02x}{:02x}{:02x}'.format(*rgb)

def hex_to_rgb(hex_color):
    return tuple(int(hex_color[i:i+2], 16) for i in (1, 3, 5))

def interpolate_color(color1, color2, factor):
    return tuple(int(color1[i] + (color2[i] - color1[i]) * factor) for i in range(3))

def main():
    # Analyze imageAlfa
    darkest_alfa, lightest_alfa = analyze_image('imageAlfa.png')
    
    # Process imageMu
    with Image.open('imageMu.png') as img_mu:
        pixels = list(img_mu.getdata())
        
    # Get unique colors and sort them
    unique_colors = sorted(set(pixels), key=lambda x: sum(x[:3]))
    color_count = len(unique_colors)
    
    # Create color mapping
    color_map = {}
    for i, color in enumerate(unique_colors):
        factor = i / (color_count - 1)
        new_color = interpolate_color(darkest_alfa, lightest_alfa, factor)
        color_map[color] = new_color
    
    # Apply color transformation
    new_pixels = [color_map[pixel] for pixel in pixels]
    
    # Create imageOmega
    img_omega = Image.new('RGB', img_mu.size)
    img_omega.putdata(new_pixels)
    img_omega.save('imageOmega.png')

if __name__ == "__main__":
    main()
